@@ -1665,7 +1665,7 @@ void rtp_session_uninit (RtpSession * session)
 		meta_rtp_transport_destroy(rtcp_meta_transport);
 
 #if (_WIN32_WINNT >= 0x0600) && defined(ORTP_WINDOWS_DESKTOP)
-#ifndef ENABLE_MICROSOFT_STORE_APP
+#if !defined(ENABLE_MICROSOFT_STORE_APP) && !defined(ORTP_WINDOWS_UWP)
 	if (session->rtp.QoSFlowID != 0)
 	{
 		ortp_message("check OS support for qwave.lib");
@@ -1687,6 +1687,8 @@ void rtp_session_uninit (RtpSession * session)
 #endif //ENABLE_MICROSOFT_STORE_APP
 #endif
 
+	if (session->rtcp.tmmbr_info.sent)
+		freemsg(session->rtcp.tmmbr_info.sent);
 	if (session->rtcp.tmmbr_info.received)
 		freemsg(session->rtcp.tmmbr_info.received);
 	if (session->rtcp.send_algo.fb_packets)
@@ -2220,7 +2222,7 @@ ORTP_PUBLIC int rtp_get_extension_header(mblk_t *packet, int id, uint8_t **data)
 
 				if (id == (int)(*tmp >> 4)) {
 					if (data) *data = tmp + 1;
-					return size;
+					return (int)size;
 				}
 
 				tmp += size + 1;
@@ -2235,7 +2237,7 @@ ORTP_PUBLIC int rtp_get_extension_header(mblk_t *packet, int id, uint8_t **data)
 
 				if (id == (int)*tmp) {
 					if (data) *data = tmp + 2;
-					return size;
+					return (int)size;
 				}
 
 				tmp += size + 2;
@@ -2520,7 +2522,7 @@ int meta_rtp_transport_recvfrom(RtpTransport *t, mblk_t *msg, int flags, struct
 	int ret;
 	MetaRtpTransportImpl *m = (MetaRtpTransportImpl*)t->data;
 	OList *elem;
-	bool_t received_via_rtcp_mux = FALSE;
+	bool_t packet_is_rtp = m->is_rtp; /* presume it is the same nature as the RtpTransport, but can be changed if rtcp-mux is used */
 
 	if (!m->has_set_session){
 		meta_rtp_set_session(t->session,m);
@@ -2557,22 +2559,22 @@ int meta_rtp_transport_recvfrom(RtpTransport *t, mblk_t *msg, int flags, struct
 			int pt = rtp_get_payload_type(msg);
 			if (pt >= 64 && pt <= 95){
 				/*this is assumed to be an RTCP packet*/
-				received_via_rtcp_mux = TRUE;
+				packet_is_rtp = FALSE;
 			}
 		}
 	}
 
-	if (received_via_rtcp_mux) {
+	if (m->is_rtp && !packet_is_rtp) {
 		if (m->other_meta_rtp) {
 			_meta_rtp_transport_recv_through_modifiers(m->other_meta_rtp, NULL, msg, flags);
 
 			if (t->session && t->session->bundle && t->session->is_primary) {
-				if (rtp_bundle_dispatch(t->session->bundle, m->is_rtp, msg, received_via_rtcp_mux)) {
+				if (rtp_bundle_dispatch(t->session->bundle, packet_is_rtp, msg)) {
 					return 0;
 				}
 			}
 
-			rtp_session_process_incoming(t->session, dupmsg(msg),FALSE, msg->reserved1, received_via_rtcp_mux);
+			rtp_session_process_incoming(t->session, dupmsg(msg),FALSE, msg->reserved1, TRUE);
 			ret = 0; /*since we directly inject in the RtpSession this RTCP packet, we shall return 0 and pass a duplicate of the message,
 			because rtp_session_rtp_recv() is going to free it.*/
 		} else {
@@ -2582,11 +2584,11 @@ int meta_rtp_transport_recvfrom(RtpTransport *t, mblk_t *msg, int flags, struct
 		ret = _meta_rtp_transport_recv_through_modifiers(t, NULL, msg, flags);
 
 		if (t->session && t->session->bundle && t->session->is_primary) {
-			if (rtp_bundle_dispatch(t->session->bundle, m->is_rtp, msg, received_via_rtcp_mux)) {
+			if (rtp_bundle_dispatch(t->session->bundle, TRUE, msg)) {
 				return 0;
 			}
 
-			ret = msgdsize(msg);
+			ret = (int)msgdsize(msg);
 		}
 	}
 
